const {
  csv,
  select,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} = d3;

const titleText = 'Total Workers vs Line Workers';

const csvUrl = [
  'https://gist.githubusercontent.com/',
  'siddhipa/', // User
  '3357f23f4ecd08f3737215f16026269e/', // Id of the Gist
  'raw/', // commit
  'nikeManufacturing.csv', // File name
].join('');

const parseRow = (d) => {
  d['Total Workers'] = +d['Total Workers'];
  d['Line Workers'] = +d['Line Workers'];
  d['% Female Workers'] = +d['% Female Workers'];
  d['% Migrant Workers'] = +d['% Migrant Workers'];
  return d;
};

const xValue = (d) => d['Total Workers'];
const xAxisLabel = 'Total Workers';
const yValue = (d) => d['Line Workers'];
const yAxisLabel = 'No. of Line Workers';

const margin = {
  top: 20,
  right: 20,
  bottom: 57,
  left: 97,
};
const radius = 5;
const width = window.innerWidth;
const height = window.innerHeight;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await csv(csvUrl, parseRow);

  const x = scaleLinear()
    .domain(extent(data, xValue))
    .range([margin.left, width - margin.right]);

  const y = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  const marks = data.map((d) => ({
    x: x(xValue(d)),
    y: y(yValue(d)),
  }));

  svg
    .selectAll('circle')
    .data(marks)
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', radius)
    .attr('opacity', 0.5);

  svg
    .append('g')
    .attr('transform', `translate(${margin.left},0)`)
    .call(axisLeft(y));

  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - margin.bottom})`
    )
    .call(axisBottom(x));

  svg
    .append('text')
    .attr('x', 400)
    .attr('y', 40)
    .attr('font-size', '25px')
    .text(titleText);

  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', 30)
    .attr('x', 0 - height / 2 - 40)
    .attr('fill', 'black')
    .attr('font-size', '20px')
    .text(yAxisLabel);

  svg
    .append('text')
    .attr('y', 490)
    .attr('x', 490)
    .attr('fill', 'black')
    .attr('font-size', '20px')
    .text(xAxisLabel);
};
main();
